@@ -24,6 +24,7 @@
 #include <gtk/gtkcellrenderertoggle.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtksignal.h>
+#include <glib/gi18n.h>
 
 #include "gconf-util.h"
 #include "gconf-marshal.h"
@@ -142,7 +143,7 @@ gconf_cell_renderer_get_size (GtkCellRenderer *cell, GtkWidget *widget, GdkRecta
 
 	if (cellvalue->value == NULL) {
 		g_object_set (G_OBJECT (cellvalue->text_renderer),
-			      "text", "<no value>",
+			      "text", _("<no value>"),
 			      NULL);
 		gtk_cell_renderer_get_size (cellvalue->text_renderer, widget, cell_area,
 					    x_offset, y_offset, width, height);
@@ -339,7 +340,7 @@ gconf_cell_renderer_render (GtkCellRenderer *cell, GdkWindow *window, GtkWidget
 
 	if (cellvalue->value == NULL) {
 		g_object_set (G_OBJECT (cellvalue->text_renderer),
-			      "text", "<no value>",
+			      "text", _("<no value>"),
 			      NULL);
 
 		gtk_cell_renderer_render (cellvalue->text_renderer, window, widget,
