@@ -26,47 +26,38 @@
 #include "gconf-editor-window.h"
 
 
-static void
-invalid_arg_error_dialog (GtkWindow  *parent,
-			  const char *key,
-			  const char *error_message)
-{
-	GtkWidget *dialog;
-
-	dialog = gtk_message_dialog_new (parent,
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_OK,
-					 _("Invalid key \"%s\": %s"),
-					 key, error_message);
-	gtk_dialog_run(GTK_DIALOG(dialog));
-	gtk_widget_destroy(dialog);
-}
-
 gint
 main (gint argc, gchar **argv)
 {
+	
 	GnomeProgram *program;
-	GValue value = { 0 };
-	poptContext pctx;
+	GOptionContext *context;
 	GtkWidget *window;
-	const char *initial_key;
+	char *description;
+	static gchar **remaining_args = NULL;
+	gchar *initial_key = NULL;
+		
+	const GOptionEntry entries[] = 
+	{
+	  { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_STRING_ARRAY, &remaining_args, NULL, N_("[KEY]") },
+	  { NULL }
+	};
 
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	description = g_strdup_printf ("- %s", _("Directly edit your entire configuration database"));
+	context = g_option_context_new (description);
+	g_free (description);
 
-	program = gnome_program_init ("gconf-editor", VERSION, 
-	                              LIBGNOMEUI_MODULE, argc, argv,
-	                              GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 
-	g_value_init (&value, G_TYPE_POINTER);
-	g_object_get_property (G_OBJECT (program),
-	                       GNOME_PARAM_POPT_CONTEXT,
-	                       &value);
-	pctx = g_value_get_pointer (&value);
-	g_value_unset (&value);
+	program = gnome_program_init (PACKAGE, VERSION, LIBGNOMEUI_MODULE,
+									argc, argv,
+									GNOME_PARAM_GOPTION_CONTEXT, context,								
+									GNOME_PARAM_APP_DATADIR, DATADIR,
+									GNOME_PARAM_NONE);
 
 	/* Register our stock icons */
 	gconf_stock_icons_register ();
@@ -74,23 +65,19 @@ main (gint argc, gchar **argv)
 	window = gconf_editor_application_create_editor_window (GCONF_EDITOR_WINDOW_TYPE_NORMAL);
 	gtk_widget_show_now (window);
 
-	initial_key = poptGetArg (pctx);
+	/* get the key specified on the command line if any. Ignore the rest */
+	initial_key = remaining_args != NULL ? remaining_args[0] : NULL;
 
-	if (initial_key != NULL) {
-		char *reason;
-
-		if (gconf_valid_key (initial_key, &reason))
-			gconf_editor_window_go_to (GCONF_EDITOR_WINDOW (window),
-			                           initial_key);
-		else {
-			invalid_arg_error_dialog (GTK_WINDOW (window),
-			                          initial_key, reason);
-			g_free (reason);
-		}
-	}
-	poptFreeContext (pctx);
-
-	gtk_main ();
+	if (initial_key != NULL)
+		gconf_editor_window_go_to (GCONF_EDITOR_WINDOW (window),initial_key);
 	
+	gtk_main ();
+
+	gnome_accelerators_sync();
+	
+	g_object_unref(program);
+
+	g_strfreev (remaining_args);
+
 	return 0;
 }
